@@ -212,10 +212,10 @@ sub _alias {
 	if $aliases->{$from};
 
     die "$entity_class: can't alias $from it's already a property!"
-	if $entity_class->meta->find_attribute_by_name($from);
+	if $entity_class->meta->get_attribute($from);
 
     die "$entity_class: attempt to alias $from to non-existant property $to - check spelling and declaration order"
-	unless $entity_class->meta->find_attribute_by_name($to);
+	unless $entity_class->meta->get_attribute($to);
 
     $opt{to} = $to;
     $aliases->{$from} = \%opt;
@@ -347,7 +347,7 @@ sub _ordered_attributes {
 
     my $meta = $class->meta;
 
-    return map {$meta->find_attribute_by_name($_)} ($class->_ordered_attribute_names);
+    return map {$meta->get_attribute($_)} ($class->_ordered_attribute_names);
 }
 
 sub _cmp_col {
@@ -442,7 +442,7 @@ sub property_types {
     my @atts = $meta->get_attribute_list;
 
     return {
-	map {$_ => $meta->find_attribute_by_name($_)->type_constraint} @atts
+	map {$_ => $meta->get_attribute($_)->type_constraint} @atts
     };
 }
 
@@ -509,7 +509,7 @@ sub set {
 	}
 
 	my $meta = $self->meta;
-	my $attribute =  $meta->find_attribute_by_name($_);
+	my $attribute =  $meta->get_attribute($_);
 	my $value = $data{$_};
 
 	if (defined $value) {
